%global srcname azure-sdk
%global common_description This project provides a set of Python packages that make it easy to access\
Management (Virtual Machines, ...) or Runtime (ServiceBus using HTTP, Batch,\
Monitor) components of Microsoft Azure Complete feature list of this repo and\
where to find Python packages not in this repo can be found on our Azure SDK for\
Python documentation.

%global _with_python2 0%{?rhel} || 0%{?fedora} <= 29
%global py2_prefix %{?rhel:python}%{?fedora:python2}
# Some Python 3 libraries required by azure-storage are not available in EL
%global _with_python3 0%{?fedora}
# - Tests disabled for Fedora (segfault occurs when running checks on Rawhide)
# - Tests require a more recent version of vcrpy library than the one available
#   in EL
%global _with_tests 0
# EL is missing recommonmark library to build documentation
%global _with_doc 0%{?fedora}
%global pydoc_prefix %{?rhel:python}%{?fedora:python%{python3_pkgversion}}
%global sphinxbuild sphinx-build%{?fedora:-%{python3_version}}

# Ignore bytecode compilation errors with Python 2 (since the library provides
# some Python 3-only files)
%global _python_bytecompile_errors_terminate_build 0%{!?_with_python2}

%global azure_storage_min_version 1.0.0
%global msrest_min_version 0.4.26
%global msrestazure_min_version 0.5.0

Name:           python-%{srcname}
Version:        4.0.0
Release:        4%{?dist}
Summary:        Microsoft Azure SDK for Python

# All packages are licensed under the MIT license, except:
# - azure-servicebus
# - azure-servicemanagement-legacy
License:        MIT and ASL 2.0
URL:            https://github.com/Azure/azure-sdk-for-python
Source0:        %{url}/archive/azure_%{version}/%{srcname}-%{version}.tar.gz
# Fix build with old versions of setuptools library
Patch0:         %{name}-4.0.0-setup.patch
# Install namespace package modules (disabled by default, may be required by
# modules depending on Azure SDK for development)
Patch1:         %{name}-4.0.0-nspkgs.patch

%if 0%{?_with_python2}
BuildRequires:  %{py2_prefix}-devel
BuildRequires:  %{py2_prefix}-setuptools
%if 0%{?_with_tests}
BuildRequires:  %{py2_prefix}-azure-devtools
BuildRequires:  %{py2_prefix}-azure-storage >= %{azure_storage_min_version}
BuildRequires:  %{py2_prefix}-msrest >= %{msrest_min_version}
BuildRequires:  %{py2_prefix}-msrestazure >= %{msrestazure_min_version}
BuildRequires:  %{py2_prefix}-pytest-cov
BuildRequires:  %{py2_prefix}-requests
BuildRequires:  %{!?rhel:%{py2_prefix}-}pyOpenSSL
BuildRequires:  %{!?rhel:%{py2_prefix}-}pytest
%endif
%endif
%if 0%{?_with_python3}
BuildRequires:  python%{python3_pkgversion}-devel
BuildRequires:  python%{python3_pkgversion}-setuptools
%if 0%{?_with_tests}
BuildRequires:  python%{python3_pkgversion}-azure-devtools
BuildRequires:  python%{python3_pkgversion}-azure-storage >= %{azure_storage_min_version}
BuildRequires:  python%{python3_pkgversion}-msrest >= %{msrest_min_version}
BuildRequires:  python%{python3_pkgversion}-msrestazure >= %{msrestazure_min_version}
BuildRequires:  python%{python3_pkgversion}-pyOpenSSL
BuildRequires:  python%{python3_pkgversion}-pytest
BuildRequires:  python%{python3_pkgversion}-pytest-cov
BuildRequires:  python%{python3_pkgversion}-requests
%endif
%endif
%if 0%{?_with_doc}
BuildRequires:  %{pydoc_prefix}-recommonmark
BuildRequires:  %{pydoc_prefix}-sphinx
BuildRequires:  %{pydoc_prefix}-sphinx_rtd_theme
%endif
BuildArch:      noarch

%description
%{common_description}


%if 0%{?_with_python2}
%package -n python2-%{srcname}
Summary:        %{summary}
Requires:       %{py2_prefix}-msrest >= %{msrest_min_version}
Requires:       %{py2_prefix}-msrestazure >= %{msrestazure_min_version}
Requires:       %{py2_prefix}-requests
Requires:       %{!?rhel:%{py2_prefix}-}pyOpenSSL
%{?python_provide:%python_provide python2-%{srcname}}

%description -n python2-%{srcname}
%{common_description}
%endif


%if 0%{?_with_python3}
%package -n python%{python3_pkgversion}-%{srcname}
Summary:        %{summary}
Requires:       python%{python3_pkgversion}-msrest >= %{msrest_min_version}
Requires:       python%{python3_pkgversion}-msrestazure >= %{msrestazure_min_version}
Requires:       python%{python3_pkgversion}-pyOpenSSL
Requires:       python%{python3_pkgversion}-requests
%{?python_provide:%python_provide python%{python3_pkgversion}-%{srcname}}

%description -n python%{python3_pkgversion}-%{srcname}
%{common_description}
%endif


%if 0%{?_with_doc}
%package doc
Summary:        Documentation for %{name}

%description doc
This package provides documentation for %{name}.
%endif


%prep
%autosetup -p0 -n %{srcname}-for-python-azure_%{version}%{?prerelease}


%build
%if 0%{?_with_python2}
%py2_build
%endif
%if 0%{?_with_python3}
%py3_build
%endif

%if 0%{?_with_doc}
%make_build -C doc/ html SPHINXBUILD=%{sphinxbuild}
rm doc/_build/html/.buildinfo
%endif


%install
%if 0%{?_with_python2}
%py2_install
%endif
%if 0%{?_with_python3}
%py3_install
%endif


%check
%if 0%{_with_tests}
PYTHONPATH=
for d in azure-*/; do
    PYTHONPATH+="$d:"
done
export PYTHONPATH=${PYTHONPATH%:}

%if 0%{?_with_python2}
py.test-%{python2_version}
%endif
%if 0%{?_with_python3}
py.test-%{python3_version}
%endif
%endif


%if 0%{?_with_python2}
%files -n python2-%{srcname}
%doc CONTRIBUTING.md README.rst
%license LICENSE.txt
%{python2_sitelib}/azure/
%{python2_sitelib}/azure_*.egg-info/
%endif


%if 0%{?_with_python3}
%files -n python%{python3_pkgversion}-%{srcname}
%doc CONTRIBUTING.md README.rst
%license LICENSE.txt
%{python3_sitelib}/azure/
%{python3_sitelib}/azure_*.egg-info/
%endif


%if 0%{?_with_doc}
%files doc
%doc doc/_build/html/
%license LICENSE.txt
%endif


%changelog
* Sat Feb 02 2019 Fedora Release Engineering <releng@fedoraproject.org> - 4.0.0-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_30_Mass_Rebuild

* Thu Nov 22 2018 Mohamed El Morabity <melmorabity@fedoraproject.org> - 4.0.0-3
- Build documentation with Python 3 on Fedora
- Fix Python 3-only file deployment
- Don't glob everything under the Python sitelib directory

* Mon Aug 06 2018 Mohamed El Morabity <melmorabity@fedoraproject.org> - 4.0.0-2
- Delete all Python 3-only files from the python2 subpackage

* Mon Aug 06 2018 Mohamed El Morabity <melmorabity@fedoraproject.org> - 4.0.0-1
- Update to 4.0.0
